@@ -2,6 +2,18 @@ require 'drb/drb'
 require 'drb/extserv'
 require 'timeout'
 
+class XArray < Array
+  def initialize(ary)
+    ary.each do |x|
+      self.push(x)
+    end
+  end
+end
+
+class XArray2 < XArray
+  include DRbUndumped
+end
+
 class DRbEx
   include DRbUndumped
 
@@ -69,6 +81,34 @@ class DRbEx
     yield(one, two)
     nil
   end
+
+  def xarray_each
+    xary = [XArray.new([0])]
+    xary.each do |x|
+      yield(x)
+    end
+    nil
+  end
+
+  def xarray2_hash
+    unless @xary2_hash
+      @xary2_hash = { "a" => XArray2.new([0]), "b" => XArray2.new([1]) }
+    end
+    DRbObject.new(@xary2_hash)
+  end
+
+  def [](key)
+    key.to_s
+  end
+
+  def to_a
+    [self]
+  end
+
+  private
+  def call_private_method
+    true
+  end
 end
 
 if __FILE__ == $0
@@ -79,7 +119,7 @@ if __FILE__ == $0
   end
 
   DRb::DRbServer.default_argc_limit(8)
-  DRb::DRbServer.default_load_limit(1024)
+  DRb::DRbServer.default_load_limit(2048)
   DRb.start_service(nil, DRbEx.new)
   es = DRb::ExtServ.new(ARGV.shift, ARGV.shift)
   DRb.thread.join
