@@ -54,7 +54,7 @@ end
 if __FILE__ == $0
   if $DEBUG
     require 'drb/timeridconv'
-    DRb.install_id_conv(TimerIdConv.new)
+    DRb.install_id_conv(DRb::TimerIdConv.new(2))
   end
 
   DRb.start_service(nil, DRbEx4.new)
